"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chai_1 = require("chai");
const index_1 = tslib_1.__importDefault(require("../../../index"));
const presets_1 = require("../../../presets");
describe("legacy linter | html-req-lang", function () {
    function createLinter(config) {
        return new index_1.default.LegacyLinter(index_1.default.rules, presets_1.presets.none, config);
    }
    it("Should not report any error when html tag as a none empty lang attribute", async function () {
        const linter = createLinter({ "html-req-lang": true });
        const html = `
      <!DOCTYPE html>
      <html lang="en">
      </html>
    `;
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
    it("Should report an error when html tag does not have a lang attribute", async function () {
        const linter = createLinter({ "html-req-lang": true });
        const html = `
      <!DOCTYPE html>
      <html>
      </html>
    `;
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
});
describe("html-req-lang", function () {
    function createLinter(rules) {
        return index_1.default.fromConfig({ rules });
    }
    it("Should not report any error when html tag as a none empty lang attribute", async function () {
        const linter = createLinter({ "html-req-lang": true });
        const html = `
      <!DOCTYPE html>
      <html lang="en">
      </html>
    `;
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
    it("Should report an error when html tag does not have a lang attribute", async function () {
        const linter = createLinter({ "html-req-lang": true });
        const html = `
      <!DOCTYPE html>
      <html>
      </html>
    `;
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
});
