"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chai_1 = require("chai");
const index_1 = tslib_1.__importDefault(require("../../../index"));
const presets_1 = require("../../../presets");
describe("legacy linter | img-req-src", function () {
    function createLinter(config) {
        return new index_1.default.LegacyLinter(index_1.default.rules, presets_1.presets.none, config);
    }
    it("Should not report any error for <img> with an src value", async function () {
        const linter = createLinter({ "img-req-src": true });
        const html = '<img src="cat.jpg" alt="A cat picture">';
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
    it("Should report an error for <img> without src alt value", async function () {
        const linter = createLinter({ "img-req-src": true });
        const html = "<img>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
    it("Should report an error for <img> with an empty src value", async function () {
        const linter = createLinter({ "img-req-src": true });
        const html = '<img src="">';
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
    it("Should check only <img> ", async function () {
        const linter = createLinter({ "img-req-src": true });
        const html = '<div src="">';
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
});
describe("img-req-src", function () {
    function createLinter(rules) {
        return index_1.default.fromConfig({ rules });
    }
    it("Should not report any error for <img> with an src value", async function () {
        const linter = createLinter({ "img-req-src": true });
        const html = '<img src="cat.jpg" alt="A cat picture">';
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
    it("Should report an error for <img> without src alt value", async function () {
        const linter = createLinter({ "img-req-src": true });
        const html = "<img>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
    it("Should report an error for <img> with an empty src value", async function () {
        const linter = createLinter({ "img-req-src": true });
        const html = '<img src="">';
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
    it("Should check only <img> ", async function () {
        const linter = createLinter({ "img-req-src": true });
        const html = '<div src="">';
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
});
