"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chai_1 = require("chai");
const index_1 = tslib_1.__importDefault(require("../../../index"));
const presets_1 = require("../../../presets");
describe("legacy linter | tag-close", function () {
    function createLinter(config) {
        return new index_1.default.LegacyLinter(index_1.default.rules, presets_1.presets.none, config);
    }
    it("Should report an error for not matching open/close tags", async function () {
        const linter = createLinter({ "tag-close": true });
        const html = "<body></div>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
    it("Should report an error per none matching open/close tags", async function () {
        const linter = createLinter({ "tag-close": true });
        const html = "<body><p></span></div>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(2);
    });
    it("Should not report an error for self closing tags", async function () {
        const linter = createLinter({ "tag-close": true });
        const html = "<br/><br>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
    it("Should not report an error for unicode chars", async function () {
        const linter = createLinter({ "tag-close": true });
        const html = "<span>&#8599;</span>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
});
describe("tag-close", function () {
    function createLinter(rules) {
        return index_1.default.fromConfig({ rules });
    }
    it("Should report an error for not matching open/close tags", async function () {
        const linter = createLinter({ "tag-close": true });
        const html = "<body></div>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
    it("Should report an error per none matching open/close tags", async function () {
        const linter = createLinter({ "tag-close": true });
        const html = "<body><p></span></div>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(2);
    });
    it("Should not report an error for self closing tags", async function () {
        const linter = createLinter({ "tag-close": true });
        const html = "<br/><br>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
    it("Should not report an error for unicode chars", async function () {
        const linter = createLinter({ "tag-close": true });
        const html = "<span>&#8599;</span>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
});
