"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chai_1 = require("chai");
const index_1 = tslib_1.__importDefault(require("../../../index"));
const presets_1 = require("../../../presets");
describe("legacy linter | tag-name-lowercase", function () {
    function createLinter(config) {
        return new index_1.default.LegacyLinter(index_1.default.rules, presets_1.presets.none, config);
    }
    it("Should report an error when tags name are not lowercased", async function () {
        const linter = createLinter({ "tag-name-lowercase": true });
        const html = "<boDY></boDY>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
    it("Should report an error pers tags not lowercased", async function () {
        const linter = createLinter({ "tag-name-lowercase": true });
        const html = "<boDY><seCtion></section></boDY>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(2);
    });
    it("Should not report an error when tags name are lowercased", async function () {
        const linter = createLinter({ "tag-name-lowercase": true });
        const html = "<body></body>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
    it("Should ignore directive", async function () {
        const linter = createLinter({ "tag-name-lowercase": true });
        const html = "<!DOCTYPE html>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
});
describe("tag-name-lowercase", function () {
    function createLinter(rules) {
        return index_1.default.fromConfig({ rules });
    }
    it("Should report an error when tags name are not lowercased", async function () {
        const linter = createLinter({ "tag-name-lowercase": true });
        const html = "<boDY></boDY>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
    it("Should report an error pers tags not lowercased", async function () {
        const linter = createLinter({ "tag-name-lowercase": true });
        const html = "<boDY><seCtion></section></boDY>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(2);
    });
    it("Should not report an error when tags name are lowercased", async function () {
        const linter = createLinter({ "tag-name-lowercase": true });
        const html = "<body></body>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
    it("Should ignore directive", async function () {
        const linter = createLinter({ "tag-name-lowercase": true });
        const html = "<!DOCTYPE html>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
});
