"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chai_1 = require("chai");
const index_1 = tslib_1.__importDefault(require("../../../index"));
const presets_1 = require("../../../presets");
describe("legacy linter | tag-name-match", function () {
    function createLinter(config) {
        return new index_1.default.LegacyLinter(index_1.default.rules, presets_1.presets.none, config);
    }
    it("Should not report an error for matching open/close tags", async function () {
        const linter = createLinter({ "tag-name-match": true });
        const html = "<body></body><Div></Div>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
    it("Should report an error for not matching open/close tags (different case)", async function () {
        const linter = createLinter({ "tag-name-match": true });
        const html = "<body></Body>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
});
describe("tag-name-match", function () {
    function createLinter(rules) {
        return index_1.default.fromConfig({ rules });
    }
    it("Should not report an error for matching open/close tags", async function () {
        const linter = createLinter({ "tag-name-match": true });
        const html = "<body></body><Div></Div>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
    it("Should report an error for not matching open/close tags (different case)", async function () {
        const linter = createLinter({ "tag-name-match": true });
        const html = "<body></Body>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
});
