"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chai_1 = require("chai");
const index_1 = tslib_1.__importDefault(require("../../../index"));
const presets_1 = require("../../../presets");
describe("legacy linter | title-no-dup", function () {
    function createLinter(config) {
        return new index_1.default.LegacyLinter(index_1.default.rules, presets_1.presets.none, config);
    }
    it("Should not report an error when title is not duplicated", async function () {
        const linter = createLinter({ "title-no-dup": true });
        const html = "<head><title>Title!</title></head>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
    it("Should report an error when title is duplicated", async function () {
        const linter = createLinter({ "title-no-dup": true });
        const html = "<head><title>Title!</title><title>Title!</title></head>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
    it("Should catch multiple duplicates", async function () {
        const linter = createLinter({ "title-no-dup": true });
        const html = "<head><title>Title!</title><title>Title!</title><title>Title!</title><title>Title!</title></head>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(3);
    });
});
describe("title-no-dup", function () {
    function createLinter(rules) {
        return index_1.default.fromConfig({ rules });
    }
    it("Should not report an error when title is not duplicated", async function () {
        const linter = createLinter({ "title-no-dup": true });
        const html = "<head><title>Title!</title></head>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(0);
    });
    it("Should report an error when title is duplicated", async function () {
        const linter = createLinter({ "title-no-dup": true });
        const html = "<head><title>Title!</title><title>Title!</title></head>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(1);
    });
    it("Should catch multiple duplicates", async function () {
        const linter = createLinter({ "title-no-dup": true });
        const html = "<head><title>Title!</title><title>Title!</title><title>Title!</title><title>Title!</title></head>";
        const issues = await linter.lint(html);
        (0, chai_1.expect)(issues).to.have.lengthOf(3);
    });
});
